@@ -29,7 +29,7 @@ pub struct UserPathParams {
 
 /// Greets a user with the given name.
 #[api::operation]
-#[get("/user/{userId}")]
+#[get("/user/{userName}")]
 #[api(
     tag(EXAMPLE_TAG),
     response(
@@ -37,9 +37,10 @@ pub struct UserPathParams {
         type(String),
         description("A user greeting"),
         example(String::from("hello Tom!"))
-    )
+    ),
+    skip(return)
 )]
-async fn greet_user(params: web::Path<UserPathParams>) -> impl Responder {
+async fn greet_user(params: web::Path<UserPathParams>) -> String {
     format!("hello {}!", params.user_name)
 }
 
@@ -57,11 +58,8 @@ pub struct UserUpdate {
 
 /// Updates a user with the given ID.
 #[api::operation]
-#[api(
-    tag(EXAMPLE_TAG2),
-    response(204)
-)]
-#[post("/user/{userId}")]
+#[api(tag(EXAMPLE_TAG2), response(204))]
+#[post("/user/{userName}")]
 async fn update_user(
     _params: web::Path<UserPathParams>,
     _body: web::Json<UserUpdate>,
